@@ -134,9 +134,17 @@ sanitize_output <- function(output) {
       word_fmt <- c("word_document",
                     "rdocx_document", "officedown::rdocx_document",
                     "word_document2", "bookdown::word_document2")
+      # unfortunately, `rmarkdown::default_output_format` only detects
+      # `html_document` on reprex, so this will only work in `github_document`
+      markdown_fmt <- c("github_document",
+                        "reprex_render",
+                        "reprex::reprex_render")
       ## change to word output format only if `output` is "default" or "flextable"
       if (any(word_fmt %in% fmt) && output_user %in% c("flextable", "default")) {
         output_format <- "word"
+      ## reprex and github: change to markdown output format only if `output` is "default"
+      } else if (any(markdown_fmt %in% fmt) && (output_user == "default")) {
+        output_format <- "markdown"
       }
     }
   }
